@@ -15,7 +15,7 @@ use WebService::Google::Reader::Constants;
 use WebService::Google::Reader::Feed;
 use WebService::Google::Reader::ListElement;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 $VERSION = eval $VERSION;
 
 __PACKAGE__->mk_accessors(qw(
@@ -546,12 +546,12 @@ sub _request {
             print "Stale ClientLogin token- retrying\n" if $self->{debug};
             $self->_login(1) or return;
             $self->_token(1) or return if $self->token;
-            return $self->_request($req,  $count++);
+            return $self->_request($req, ++$count);
         }
         elsif ($res->header('X-Reader-Google-Bad-Token')) {
             print "Stale T token- retrying\n" if $self->{debug};
             $self->_token(1);
-            return $self->_request($req,  $count++);
+            return $self->_request($req, ++$count);
         }
 
         $self->error($res->status_line . ' - ' . $res->decoded_content);
